@@ -2,8 +2,6 @@
 
 from __future__ import annotations
 
-import logging
-
 from pathlib import Path
 from typing import TYPE_CHECKING, cast
 
@@ -15,9 +13,6 @@ if TYPE_CHECKING:
     from collections.abc import MutableMapping
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Roles(AnsibleGalaxyBase):
     """Role-specific Ansible Galaxy dependency handling.
 
